# -*- coding: utf-8 -*-
# @author: leesoar

"""errors"""

AnoleUserAgentError = type("AnoleUserAgentError", (Exception, ), {})
AnoleNameError = type("AnoleNameError", (Exception, ), {})
AnoleCrawlError = type("AnoleCrawlError", (Exception, ), {})
